@@ -139,13 +139,21 @@ from unittest import TextTestResult
 
 from sysconfig import get_platform
 
+import setuptools
+import pkg_resources
+
 # We need to be able to test BDB releases, even if the license is incompatible
 os.environ['YES_I_HAVE_THE_RIGHT_TO_USE_THIS_BERKELEY_DB_VERSION'] = ''
 
 
 PROGRAM = sys.argv[0]
-version = sys.version_info
-PLAT_SPEC = f'{get_platform()}-{version.major}.{version.minor}'
+min_version = pkg_resources.parse_version('62.1.0')
+if pkg_resources.parse_version(setuptools.__version__) >= min_version:
+    PLAT_SPEC = f'{get_platform()}-{sys.implementation.cache_tag}'
+else:
+    version = sys.version_info
+    PLAT_SPEC = f'{get_platform()}-{version.major}.{version.minor}'
+
 # This hack copied from distutils.command.build.  Too bad distutils
 # doesn't export its build/ directory naming scheme as a library function.
 if hasattr(sys, 'gettotalrefcount'):
@@ -271,6 +279,7 @@ class PathInit:
         # Hack sys.path
         self.cwd = os.getcwd()
         sys.path[0] = os.path.join(self.cwd, self.libdir)
+        os.environ['BERKELEYDB_SO_PATH'] = sys.path[0]
 
 
 def match(rx, s):
